<?php

return [
    'Names' => [
        'Adlm' => 'Adlam',
        'Arab' => 'Arabic',
        'Aran' => 'Nastaliq',
        'Armn' => 'Armenian',
        'Beng' => 'Bangla',
        'Bopo' => 'Bopomofo',
        'Brai' => 'Braille',
        'Cakm' => 'Chakma',
        'Cans' => 'Unified Canadian Aboriginal Syllabics',
        'Cher' => 'Cherokee',
        'Cyrl' => 'Cyrillic',
        'Deva' => 'Devanagari',
        'Ethi' => 'Ethiopic',
        'Geor' => 'Georgian',
        'Grek' => 'Greek',
        'Gujr' => 'Gujarati',
        'Guru' => 'Gurmukhi',
        'Hanb' => 'Han na may Bopomofo',
        'Hang' => 'Hangul',
        'Hani' => 'Han',
        'Hans' => 'Pinasimple',
        'Hant' => 'Tradisyonal',
        'Hebr' => 'Hebrew',
        'Hira' => 'Hiragana',
        'Hrkt' => 'Japanese syllabaries',
        'Jamo' => 'Jamo',
        'Jpan' => 'Japanese',
        'Kana' => 'Katakana',
        'Khmr' => 'Khmer',
        'Knda' => 'Kannada',
        'Kore' => 'Korean',
        'Laoo' => 'Lao',
        'Latn' => 'Latin',
        'Mlym' => 'Malayalam',
        'Mong' => 'Mongolian',
        'Mtei' => 'Meitei Mayek',
        'Mymr' => 'Myanmar',
        'Nkoo' => 'N’Ko',
        'Olck' => 'Ol Chiki',
        'Orya' => 'Odia',
        'Rohg' => 'Hanifi',
        'Sinh' => 'Sinhala',
        'Sund' => 'Sundanese',
        'Syrc' => 'Syriac',
        'Taml' => 'Tamil',
        'Telu' => 'Telugu',
        'Tfng' => 'Tifinagh',
        'Thaa' => 'Thaana',
        'Thai' => 'Thai',
        'Tibt' => 'Tibetan',
        'Vaii' => 'Vai',
        'Yiii' => 'Yi',
        'Zmth' => 'Mathematical Notation',
        'Zsye' => 'Emoji',
        'Zsym' => 'Mga Simbolo',
        'Zxxx' => 'Hindi Nakasulat',
        'Zyyy' => 'Karaniwan',
    ],
];
